@@ -16,10 +16,8 @@ import android.bluetooth.BluetoothManager;
 import android.bluetooth.BluetoothProfile;
 import android.bluetooth.le.AdvertiseCallback;
 import android.bluetooth.le.AdvertiseData;
-import android.bluetooth.le.AdvertiseData.Builder;
 import android.bluetooth.le.AdvertiseSettings;
 import android.bluetooth.le.BluetoothLeAdvertiser;
-import android.os.ParcelUuid;
 import android.os.Build;
 import android.util.Log;
 import android.util.Pair;
@@ -806,6 +804,15 @@ class QtBluetoothLEServer {
         }
     }
 
+    // API-level < 33
+    @SuppressWarnings("deprecation")
+    private void notifyCharacteristicChange(BluetoothDevice device,
+                                            BluetoothGattCharacteristic characteristic,
+                                            boolean confirm)
+    {
+        mGattServer.notifyCharacteristicChanged(device, characteristic, confirm);
+    }
+
     /*
         Check the client characteristics configuration for the given characteristic
         and sends notifications or indications as per required.
@@ -832,7 +839,7 @@ class QtBluetoothLEServer {
                         mGattServer.notifyCharacteristicChanged(device, characteristic, false,
                                   ((QtBluetoothGattCharacteristic)characteristic).getLocalValue());
                     } else {
-                        mGattServer.notifyCharacteristicChanged(device, characteristic, false);
+                        notifyCharacteristicChange(device, characteristic, false);
                     }
                 } else if (Arrays.equals(clientCharacteristicConfig,
                                          BluetoothGattDescriptor.ENABLE_INDICATION_VALUE)) {
@@ -840,7 +847,7 @@ class QtBluetoothLEServer {
                         mGattServer.notifyCharacteristicChanged(device, characteristic, true,
                                   ((QtBluetoothGattCharacteristic)characteristic).getLocalValue());
                     } else {
-                        mGattServer.notifyCharacteristicChanged(device, characteristic, true);
+                        notifyCharacteristicChange(device, characteristic, true);
                     }
                 }
             }
